FileUtil class
File utilities used by the Linux implementation of shared_preferences_plus.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
readPreferences(
SharedPreferencesPlusOptions options) → Future< Map< String, Object?> > -
Reads stored preferences for the provided
options. -
writePreferences(
SharedPreferencesPlusOptions options, Map< String, Object?> preferences) → Future<void> -
Persists
preferencesfor the providedoptions.